@@ -18,9 +18,11 @@ from .factor.inferencetypes import (
     Pose2Point2BearingRange,
     Pose2Point2Range,
     Pose2Pose2,
+    Pose3Pose3,
     Prior,
     PriorPoint2,
     PriorPose2,
+    PriorPose3,
 )
 from .navabilityclient import (
     NavAbilityClient,
@@ -34,3 +36,5 @@ from .statusmessage import MutationUpdate, StatusMessage
 from .variable.ppe import Ppe
 from .variable.variable import Variable, VariableSkeleton, VariableSummary, VariableType
 from .variable.variablenodedata import VariableNodeData
+
+from .blob.blob import BlobEntry
\ No newline at end of file
