@@ -58,9 +58,12 @@ def GraphVizApp(client, variableStartsWith=None):
 def MapVizApp(client, variableStartsWith=None):
     geometry_vis_link = f"https://app.navability.io/cloud/map/?userId={client.userId}&robotStartsWith={client.robotId}&sessionStartsWith={client.sessionId}"  # noqa: E501, B950
     if variableStartsWith is None:
+        # reset the filter
         geometry_vis_link = geometry_vis_link + "&variableStartsWith"
+    else:
         if 0 < len(variableStartsWith):
-            geometry_vis_link = geometry_vis_link + "=" + variableStartsWith
+            # this defines a filter
+            geometry_vis_link = geometry_vis_link + "&variableStartsWith=" + variableStartsWith
     print(geometry_vis_link)
     try:
         return md(
