@@ -6,6 +6,7 @@ from gql import gql
 from navability.common.mutations import GQL_ADDVARIABLE
 from navability.common.queries import (
     GQL_FRAGMENT_VARIABLES,
+    GQL_LISTVARIABLES,
     GQL_GETVARIABLE,
     GQL_GETVARIABLES,
 )
@@ -46,8 +47,25 @@ async def _addVariable(navAbilityClient: NavAbilityClient, client: Client, v: Va
 
 
 def addVariable(
-    client: NavAbilityClient, context: Client, variable_or_label, varType=None
+    client: NavAbilityClient, 
+    context: Client, 
+    variable_or_label, 
+    varType=None
 ):
+    """ Add a variable to the graph.
+
+    Args:
+        client (NavAbilityClient): client connection to API server
+        context (Client): Unique context with (user, robot, session)
+        variable_or_label (Variable or string): The variable to add.
+        varType (VariableType, optional): Pose2, Pose3, etc. Defaults to None.
+
+    Raises:
+        NotImplementedError: _description_
+
+    Returns:
+        _type_: _description_
+    """
     if isinstance(variable_or_label, Variable):
         return _addVariable(client, context, variable_or_label)
     # TODO standardise varType to string or VariableType after design discussion
@@ -61,22 +79,65 @@ def addVariable(
 
 
 async def listVariables(
-    navAbilityClient: NavAbilityClient,
-    client: Client,
+    client: NavAbilityClient,
+    context: Client,
     regexFilter: str = ".*",
     tags: List[str] = None,
     solvable: int = 0,
 ) -> List[str]:
-    variables = await getVariables(
-        navAbilityClient,
-        client,
-        detail=QueryDetail.SKELETON,
-        regexFilter=regexFilter,
-        tags=tags,
-        solvable=solvable,
+    """Get a list of Variable labels in the graph.
+
+    Args:
+        client (NavAbilityClient): client connection to API server
+        context (Client): Unique context with (user, robot, session)
+        regexFilter (str, optional): Filter on variable label. Defaults to ".*".
+        tags (List[str], optional): Variables can have string tags. Defaults to None.
+        solvable (int, optional): Whether this variable can be used in solving yet. Defaults to 0.
+
+    Returns:
+        List[str]: Async task returning a list of Variable labels.
+    """
+    params = {
+        "userId": context.userId,
+        "robotId": context.robotId,
+        "sessionId": context.sessionId,
+    }
+    logger.debug(f"Query params: {params}")
+    res = await client.query(
+        QueryOptions(gql(GQL_LISTVARIABLES), params)
     )
-    result = [v.label for v in variables]
-    return result
+    if (
+        "users" not in res
+        or len(res["users"]) != 1
+        or len(res["users"][0]["robots"]) != 1
+        or len(res["users"][0]["robots"][0]["sessions"]) != 1
+        or "variables" not in res["users"][0]["robots"][0]["sessions"][0]
+    ):
+        # Debugging information
+        if len(res["users"]) != 1:
+            logger.warn("User not found in result, returning empty list")
+        if len(res["users"][0]["robots"]) != 1:
+            logger.warn("Robot not found in result, returning empty list")
+        if len(res["users"][0]["robots"][0]["sessions"]) != 1:
+            logger.warn("Robot not found in result, returning empty list")
+        return []
+    vl = []
+    _lb = lambda s: s['label']
+    resvar = res['users'][0]['robots'][0]['sessions'][0]['variables']
+    [vl.append(_lb(v)) for v in resvar]
+    return vl
+    # # LEGACY
+    # variables = await getVariables(
+    #     client,
+    #     context,
+    #     detail=QueryDetail.SKELETON,
+    #     regexFilter=regexFilter,
+    #     tags=tags,
+    #     solvable=solvable,
+    # )
+    # result = [v.label for v in variables]
+    # return result
+
 
 
 # Alias
@@ -84,17 +145,30 @@ ls = listVariables
 
 
 async def getVariables(
-    navAbilityClient: NavAbilityClient,
-    client: Client,
+    client: NavAbilityClient,
+    context: Client,
     detail: QueryDetail = QueryDetail.SKELETON,
     regexFilter: str = ".*",
     tags: List[str] = None,
     solvable: int = 0,
 ) -> List[VariableSkeleton]:
+    """Get a list of Variable from a graph using various filters.
+
+    Args:
+        client (NavAbilityClient): client connection to API server
+        context (Client): Unique context with (user, robot, session)
+        detail (QueryDetail, optional): Defaults to QueryDetail.SKELETON.
+        regexFilter (str, optional): Filter on variable label. Defaults to ".*".
+        tags (List[str], optional): Variables can have string tags. Defaults to None.
+        solvable (int, optional): Whether this variable can be used in solving yet. Defaults to 0.
+
+    Returns:
+        List[VariableSkeleton]: Async task returning a list of VariableSkeleton
+    """
     params = {
-        "userId": client.userId,
-        "robotIds": [client.robotId],
-        "sessionIds": [client.sessionId],
+        "userId": context.userId,
+        "robotIds": [context.robotId],
+        "sessionIds": [context.sessionId],
         "variable_label_regexp": regexFilter,
         "variable_tags": tags if tags is not None else ["VARIABLE"],
         "solvable": solvable,
@@ -102,7 +176,7 @@ async def getVariables(
         "fields_full": detail == QueryDetail.FULL,
     }
     logger.debug(f"Query params: {params}")
-    res = await navAbilityClient.query(
+    res = await client.query(
         QueryOptions(gql(GQL_FRAGMENT_VARIABLES + GQL_GETVARIABLES), params)
     )
     logger.debug(f"Query result: {res}")
@@ -132,11 +206,15 @@ async def getVariables(
     ]
 
 
-async def getVariable(navAbilityClient: NavAbilityClient, client: Client, label: str):
-    params = client.dump()
+async def getVariable(
+    client: NavAbilityClient, 
+    context: Client, 
+    label: str
+):
+    params = context.dump()
     params["label"] = label
     logger.debug(f"Query params: {params}")
-    res = await navAbilityClient.query(
+    res = await client.query(
         QueryOptions(gql(GQL_FRAGMENT_VARIABLES + GQL_GETVARIABLE), params)
     )
     logger.debug(f"Query result: {res}")
